<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=pl
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Aktywuj wtyczkę',
	'affichage' => 'Wyświetlanie',
	'aide_non_disponible' => 'Ta część pomocy on-line nie jest jeszcze dostępna w tym języku.',
	'annuler_recherche' => 'Anuluj wyszukiwanie',
	'auteur' => 'Autor:',
	'avis_acces_interdit' => 'Dostęp zabroniony.',
	'avis_article_modifie' => 'Uwaga, @nom_auteur_modif@ pracował nad tym artykułem @date_diff@ minut temu.',
	'avis_aucun_resultat' => 'Brak wyników szukania.',
	'avis_base_inaccessible' => 'Połączenie z bazą danych @base@ jest niemożliwe.',
	'avis_chemin_invalide_1' => 'Ścieżka, którą wybrałeś',
	'avis_chemin_invalide_2' => 'wydaje się nieprawidłowa. Proszę powrócić na poprzednią stronę w celu weryfikacji informacji.',
	'avis_connexion_echec_1' => 'Połączenie z bazą danych nie powiodło się.',
	'avis_connexion_echec_2' => 'Powróć do poprzedniej strony i zweryfikuj podane informacje.',
	'avis_connexion_echec_3' => '<b>Uwaga</b> W przypadku wielu serwerów musisz <b>poprosić</b> o uaktywnienie dostępu do bazy danych, aby móc z niej korzystać. Jeśli nie możesz się połączyć, upewnij się, czy poprosiłeś o dostęp.',
	'avis_connexion_erreur_nom_base' => 'Nazwa bazy danych powinno zawierać tylko litery, cyfry i łączniki.',
	'avis_connexion_ldap_echec_1' => 'Połączenie z LDAP nie powiodło się.',
	'avis_connexion_ldap_echec_2' => 'Powróć do poprzedniej strony i zweryfikuj podane informacje.',
	'avis_connexion_ldap_echec_3' => 'Nie używaj wsparcia LDAP do importu użytkowników.', # MODIF
	'avis_deplacement_rubrique' => 'Uwaga! Ten dział zawiera @contient_breves@ news@scb@: jeśli chcesz go przenieść, proszę zaznacz to okienko.',
	'avis_erreur_connexion_mysql' => 'Błąd połączenia z SQL',
	'avis_espace_interdit' => '<b>Dostęp zabroniony</b> <div>SPIP jest już zainstalowany.</div>',
	'avis_lecture_noms_bases_1' => 'Program instalacyjny nie może odczytać nazw dotychczas zainstalowanych baz danych.',
	'avis_lecture_noms_bases_2' => 'Żadna baza danych nie jest dostępna, lub funkcja listingu baz danych nie działa
   ze względów bezpieczeństwa(co jest częstym przypadkiem wielu hostów).',
	'avis_lecture_noms_bases_3' => 'W drugim przypadku, do użytku może nadawać się baza danych nazwana Twoim loginem :',
	'avis_non_acces_page' => 'Nie masz dostępu do tej strony.',
	'avis_operation_echec' => 'Operacja nie powiodła się.',
	'avis_operation_impossible' => 'Operacja niemożliwa',
	'avis_suppression_base' => 'OSTRZEŻENIE, usunięcie danych jest nieodwracalne',

	// B
	'bouton_acces_ldap' => 'Dodaj dostęp do LDAP',
	'bouton_ajouter' => 'Dodaj',
	'bouton_annuler' => 'Anuluj',
	'bouton_cache_activer' => 'Ponownie uaktywnić pamięć podręczną', # RELIRE
	'bouton_cache_desactiver' => 'Tymczasowo wyłączyć pamięć podręczną', # RELIRE
	'bouton_demande_publication' => 'Prośba o publikację artykułu',
	'bouton_desactive_tout' => 'Wyłącz wszystko',
	'bouton_desinstaller' => 'Odinstaluj',
	'bouton_effacer_tout' => 'Usuń WSZYSTKO',
	'bouton_envoyer_message' => 'Wiadomość końcowa: wysłano',
	'bouton_fermer' => 'Zamknij',
	'bouton_mettre_a_jour_base' => 'Aktualizuj bazę danych',
	'bouton_modifier' => 'Modyfikuj',
	'bouton_radio_afficher' => 'Pokaż',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Pojawić się na liście zalogowanych redaktorów', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Wysyłaj ogłoszenia na adres :',
	'bouton_radio_envoi_liste_nouveautes' => 'Wysyłaj najnowszą listę newsów',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Nie pokazuj w liście redaktorów', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Nie wysyłaj żadnych zawiadomień redakcyjnych',
	'bouton_redirection' => 'PRZEKIERUJ',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Zresetuj do wartości domyślnych.', # RELIRE
	'bouton_relancer_installation' => 'Uruchom ponownie instalację',
	'bouton_reset_password' => 'Wygeneruj nowe hasło i wyślij je e-mailem', # RELIRE
	'bouton_suivant' => 'Następny',
	'bouton_tenter_recuperation' => 'Próba naprawy',
	'bouton_test_proxy' => 'Test proxy',
	'bouton_vider_cache' => 'Opróżnij cache',

	// C
	'cache_modifiable_webmestre' => 'Te parametry może zmieniać webmaster serwisu.', # MODIF
	'calendrier_synchro' => 'Jeśli używasz programów - terminarzy kompatybinych z <b>iCal</b>, możesz go zsynchronizować z informacjami tego serwisu.',
	'config_activer_champs' => 'Włącz następujące pola',
	'config_choix_base_sup' => 'Wybierz bazę danych na tym serwerze.',
	'config_erreur_base_sup' => 'SPIP nie ma dostępu do listy dostępnych baz danych',
	'config_info_base_sup' => 'Jeśli musisz zapytać innych baz danych za pomocą SPIP, czy na tym serwerze SQL czy gdzie indziej, należy użyć tego formularza do ich podawania. Jeśli zostawisz jakieś pola puste, zostaną wykorzystywane szczegóły połączeń do głównej bazy danych.',
	'config_info_base_sup_disponibles' => 'Dodatkowe bazy danych do których mogą być wysyłane pytania:',
	'config_info_enregistree' => 'Nowa konfiguracja została zapisana.',
	'config_info_logos' => 'Każdy element strony może mieć logo, a także logo roll-over.',
	'config_info_logos_utiliser' => 'Użyj logo',
	'config_info_logos_utiliser_non' => 'Nie używaj logo',
	'config_info_logos_utiliser_survol' => 'Używaj logo roll-over',
	'config_info_logos_utiliser_survol_non' => 'Nie używaj logo roll-over',
	'config_info_redirection' => 'Włączając tę opcję, możesz tworzyć artykuły wirtualne, odnoszące się do artykułów opublikowanych na innych stronach (z lub bez SPIPa).',
	'config_redirection' => 'Wirtualne artykuły',
	'config_titre_base_sup' => 'Deklaracja dodatkowej bazy danych',
	'config_titre_base_sup_choix' => 'Wybierz dodatkową bazę danych',
	'connexion_ldap' => 'Połączenie:',
	'creer_et_associer_un_auteur' => 'Utwórz i przyłącz autora',

	// D
	'date_mot_heures' => 'godz.',

	// E
	'ecran_securite' => '+ ekran bezpieczeństwa @version@',
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'en_savoir_plus' => 'Aby dowiedzieć się więcej',
	'entree_adresse_annuaire' => 'Adres katalogu',
	'entree_adresse_email' => 'Twój adres e-mail',
	'entree_adresse_email_2' => 'Adres e-mailowy',
	'entree_base_donnee_1' => 'Adres bazy danych',
	'entree_base_donnee_2' => '(Często adres ten jest taki sam, jak adres strony, czasem odpowiada nazwie «serwera lokalnego», a czasem jest pozostawiony pusty.)',
	'entree_biographie' => 'Krótka biografia w kilku słowach.',
	'entree_chemin_acces' => '<b>Podaj</b> ścieżkę dostępu:',
	'entree_cle_pgp' => 'Twój klucz PGP',
	'entree_cle_pgp_2' => 'Klucz PGP',
	'entree_contenu_rubrique' => '(Tematyka działu w kilku słowach.)',
	'entree_identifiants_connexion' => 'Identyfikatory połączenia...',
	'entree_identifiants_connexion_2' => 'Identyfikatory połączeń',
	'entree_informations_connexion_ldap' => 'Proszę w ten formularz wpisać informacje o połączeniu LDAP. Uzyskać je można od administratora systemu lub sieci.', # MODIF
	'entree_infos_perso' => 'Kim jesteś?',
	'entree_infos_perso_2' => 'Kto jest autorem?',
	'entree_interieur_rubrique' => 'W dziale:',
	'entree_liens_sites' => '<b>Łącza hipertekstowe</b> (referencje, strony do odwiedzenia...)',
	'entree_login' => 'Twój login',
	'entree_login_connexion_1' => 'Login połączenia',
	'entree_login_connexion_2' => '(Czasem jest taki, jak Twój login FTP, a czasem jest pozostawiony pusty)',
	'entree_mot_passe' => 'Twoje hasło',
	'entree_mot_passe_1' => 'Hasło połączenia',
	'entree_mot_passe_2' => '(Czasem jest takie, jak Twoje hasło dostępu FTP, a czasem jest pozostawione puste)',
	'entree_nom_fichier' => 'Proszę wpisać nazwę pliku @texte_compresse@:',
	'entree_nom_pseudo' => 'Twoje imię lub alias',
	'entree_nom_pseudo_1' => '(Twoje imię lub alias)',
	'entree_nom_pseudo_2' => 'Imię lub pseudonim',
	'entree_nom_site' => 'Nazwa Twojej strony',
	'entree_nom_site_2' => 'Nazwa strony autora',
	'entree_nouveau_passe' => 'Nowe hasło',
	'entree_passe_ldap' => 'Hasło',
	'entree_port_annuaire' => 'Numer portu katalogu',
	'entree_signature' => 'Podpis',
	'entree_titre_obligatoire' => '<b>Tytuł</b> [Obowiązkowo]<br />',
	'entree_url' => 'URL Twojej strony',
	'entree_url_2' => 'Strona URL',
	'erreur_connect_deja_existant' => 'Serwer o tej nazwie już istnieje.',
	'erreur_nom_connect_incorrect' => 'Nazwa serwera nie jest dozwolona',
	'erreur_plugin_attribut_balise_manquant' => 'Brakujący atrybut @attribut@ w tagu @balise@.', # RELIRE
	'erreur_plugin_desinstalation_echouee' => 'Dezinstalacja wtyczki się nie powiodła . Jednakże, możesz ją wyłączyć.',
	'erreur_plugin_fichier_absent' => 'Brak pliku',
	'erreur_plugin_fichier_def_absent' => 'Brak pliku definicji',
	'erreur_plugin_nom_fonction_interdit' => 'Nieprawidłowa nazwa funkcji',
	'erreur_plugin_nom_manquant' => 'Brak nazwy rozszerzenia',
	'erreur_plugin_prefix_manquant' => 'Nie zdefiniowana nazwa rozszerzenia',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; nie ma w pliku definicji',
	'erreur_plugin_version_manquant' => 'Brakuje wersji rozszerzenia',

	// H
	'htaccess_a_simuler' => 'Ostrzeżenie: Konfiguracja serwera HTTP nie obejmuje plików @ htaccess @. Aby zapewnić dobre bezpieczeństwo, musisz zmodyfikować tę konfigurację lub sprawdzić, czy @ constants @ (w pliku mes_options.php) mają wartość katalogu poza @ document_root @.', # RELIRE
	'htaccess_inoperant' => 'htaccess nieczynny',

	// I
	'ical_info1' => 'Na tej stronie prezentujemy różne metody pozostanie w kontakcie z działalnością serwisu.',
	'ical_info2' => 'Aby przeczytać więcej na ten temat, idź na stronę <a href="@spipnet@">dokumentacja SPIPa</a>.',
	'ical_info_calendrier' => 'Do Twojej dyspozycji są dwa kalendarze. Jeden pokazuje mapę strony wraz ze wszystkimi opublikowanymi artykułami. Drugi zawiera ogłoszenia redakcyjne oraz Twoje ostatni wiadomości prywatne : tylko Ty masz do niego dostęp za hasłem.',
	'ical_methode_http' => 'Ściągnij',
	'ical_methode_webcal' => 'Synchronizacja (webcal://)',
	'ical_texte_prive' => 'Ten kalendarz, wyłącznie do użytku osobistego, informuje Cię o działalności redakcyjnej w strefie prywatnej (zadania, spotkania, proponowane artykuły i newsy).',
	'ical_texte_public' => 'Ten kalendarz pozawala śledzić aktywność redakcyjną serwisu (opublikowane artykuły i newsy).',
	'ical_texte_rss' => 'Możesz syndykować nowości z tego serwisu w jakimkolwiek czytniku plików formatu XML/RSS (Rich Site Summary). Ten format pozwala SPIP odczytywać nowości opublikowane w innych serwisach (serwisach syndykowanych).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista mailingowa',
	'ical_titre_rss' => 'Pliki syndykacji',
	'icone_accueil' => 'Strona główna',
	'icone_activer_cookie' => 'Aktywuj cookies korespondencji',
	'icone_activite' => 'Opinia',
	'icone_admin_plugin' => 'Zarządzanie rozszerzeniami',
	'icone_administration' => 'Konserwacja',
	'icone_afficher_auteurs' => 'Pokaż autorów',
	'icone_afficher_visiteurs' => 'Pokaż odwiedzających',
	'icone_arret_discussion' => 'Zaprzestań udziału w tej dyskusji',
	'icone_calendrier' => 'Kalendarz',
	'icone_configuration' => 'Konfiguracja',
	'icone_creer_auteur' => 'Stwórz nowego autora i przypisz go do tego artykułu',
	'icone_creer_mot_cle' => 'Stwórz nowe słowo kluczowe i skojarz je z tym artykułem',
	'icone_creer_rubrique_2' => 'Utwórz nowy dział',
	'icone_developpement' => 'Tworzenie', # RELIRE
	'icone_edition' => 'Edytuj',
	'icone_ma_langue' => 'Mój język',
	'icone_mes_infos' => 'Moje dane',
	'icone_mes_preferences' => 'Preferencje',
	'icone_modifier_article' => 'Zmień ten artykuł',
	'icone_modifier_rubrique' => 'Zmień ten dział',
	'icone_publication' => 'Publikowanie',
	'icone_relancer_signataire' => 'Skontaktuj się ponownie z sygnotariuszem',
	'icone_retour' => 'Powrót',
	'icone_retour_article' => 'Powrót do artykułu',
	'icone_squelette' => 'Szablony',
	'icone_suivi_publication' => 'śledzenie publikacji',
	'icone_supprimer_cookie' => 'Usuń cookies sesji',
	'icone_supprimer_rubrique' => 'Usuń ten dział',
	'icone_supprimer_signature' => 'Usuń ten podpis',
	'icone_valider_signature' => 'Zatwierdź ten podpis',
	'image_administrer_rubrique' => 'Możesz zarządzać tym działem',
	'impossible_modifier_login_auteur' => 'Login nie może zostać zmieniony.', # MODIF
	'impossible_modifier_pass_auteur' => 'Hasło nie może zostać zmienione.', # MODIF
	'info_1_article' => '1 artykuł',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 wiadomość',
	'info_1_mot_cle' => '1 słowo kluczowe',
	'info_1_rubrique' => '1 sekcja',
	'info_1_visiteur' => '1 gość',
	'info_activer_cookie' => 'Możesz uaktywnić <b>cookies korespondecji</b>, co ci
 pozwoli przechodzić łatwo pomiędzy stroną publiczną a prywatną.',
	'info_activer_menu_developpement' => 'Pokaż menu Rozwój', # RELIRE
	'info_admin_etre_webmestre' => 'Daj mi prawa administratora sieci',
	'info_admin_je_suis_webmestre' => 'Jestem <b>webmasterem</b>',
	'info_admin_statuer_webmestre' => 'Daj użytkownikowi prawa webmastera.', # MODIF
	'info_admin_webmestre' => 'Ten administrator jest <b>webmesterem</b>', # MODIF
	'info_administrateur' => 'Administrator', # MODIF
	'info_administrateur_1' => 'Administrator', # MODIF
	'info_administrateur_2' => 'strony (<i>korzystaj uważnie</i>)',
	'info_administrateur_site_01' => 'Jeśli jesteś administratorem strony, proszę', # MODIF
	'info_administrateur_site_02' => 'kliknij na ten link',
	'info_administrateurs' => 'Administratorzy', # MODIF
	'info_administrer_rubrique' => 'Możesz zarządzać tym działem',
	'info_adresse' => 'na adres:',
	'info_adresse_desinscription' => 'Adres rezygnacji z subskrypcji :', # RELIRE
	'info_adresse_url' => 'URL Twojej publicznej strony',
	'info_afficher_par_nb' => 'pokaż',
	'info_aide_en_ligne' => 'SPIP Pomoc Online',
	'info_ajout_image' => 'Kiedy dodajesz do artykułu obrazki jako załączniki,
  SPIP może automatycznie utworzyć winiety (thumbnails) ze
  wstawionych obrazków. Pozwoli to na, na przykład, automatyczne
  utworzenie galerii lub portfolio.',
	'info_ajouter_rubrique' => 'Dodaj dział do zarządzania :',
	'info_annonce_nouveautes' => 'Zapowiedzi najnowszych newsów',
	'info_article' => 'artykuł',
	'info_article_2' => 'artykuły',
	'info_article_a_paraitre' => 'Artykuły ustawione do publikacji',
	'info_articles_02' => 'artykuły',
	'info_articles_2' => 'Artykuły',
	'info_articles_auteur' => 'Artykuły tego autora',
	'info_articles_miens' => 'Moje artykuły',
	'info_articles_tous' => 'Wszystkie artykuły',
	'info_articles_trouves' => 'Artykuły znalezione',
	'info_attente_validation' => 'Twoje artykuły oczekujące zatwierdzenia',
	'info_aucun_article' => 'Brak artykułów',
	'info_aucun_auteur' => 'Brak autorów',
	'info_aucun_message' => 'Brak wiadomości',
	'info_aucun_rubrique' => 'Brak działu',
	'info_aujourdhui' => 'dziś:',
	'info_auteur_gere_rubriques' => 'Ten autor zarządza następującymi sekcjami:',
	'info_auteur_gere_toutes_rubriques_2' => 'Zarządzam <b>wszystkimi sekcjami</b>', # RELIRE
	'info_auteurs' => 'Autorzy',
	'info_auteurs_par_tri' => 'Autorzy@partri@',
	'info_auteurs_trouves' => 'Autorzy znalezieni',
	'info_authentification_externe' => 'Zewnętrzne uwierzytelnienie',
	'info_avertissement' => 'Ostrzeżenie',
	'info_barre_outils' => 'z jego paska narzędzi?',
	'info_base_installee' => 'Struktura Twojej bazy danych została zainstalowana.',
	'info_bio' => 'Biografia',
	'info_cache_desactive' => 'Pamięć podręczna jest tymczasowo wyłączona.',
	'info_chapeau' => 'Wstęp',
	'info_chapeau_2' => 'Wstęp:',
	'info_chemin_acces_1' => 'Opcje: <b>Ścieżka dostępu do katalogu</b>',
	'info_chemin_acces_2' => 'Powinniście w tym momencie skonfigurować ścieżkę dostępu do spisu. Ta informacja jest niezbędna do tego by odczytywać profile użytkowników zawarte w spisie.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcje: <b>Ścieżka dostępu do katalogu</b>',
	'info_choix_base' => 'Trzeci krok:',
	'info_classement_1' => '<sup>er</sup> na @liste@',
	'info_classement_2' => '<sup>e</sup> na @liste@',
	'info_code_acces' => 'Zapamiętaj swoje kody dostępu!',
	'info_config_suivi' => 'Jeśli ten adres odpowiada liście subskrypcyjnej, możecie wpisać poniżej adres, za któego pomocą uczestnicy serwisu mogą się zapisać. Adres ten może być URL-em (np. stroną służącą do zapisywania się na listę przez internet), albo adresem e-mail opatrzonym stosownym tematem (np.: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Możesz automatycznie, za pomocą poczty elektronicznej otrzymywać ogłoszenia dotyczące aktywności redakcyjnej tego serwisu. W tym celu powinnieneś się zapisać na listę mailową.',
	'info_confirmer_passe' => 'Potwierdź nowe hasło:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Uwaga: poniższe pola zostały zmodyfikowane w innym miejscu. Dlatego Twoje zmiany na tych polach nie zostały zapisane.',
	'info_conflit_edition_differences' => 'Różnice:',
	'info_conflit_edition_version_enregistree' => 'Zapisana wersja:',
	'info_conflit_edition_votre_version' => 'Twoja wersja:',
	'info_connexion_base' => 'Próba połączenia z bazą danych',
	'info_connexion_base_donnee' => 'Połączenie z bazą danych',
	'info_connexion_ldap_ok' => '<b>Połączenie LDAP powiodło się.<b><p> Idź do następnego etapu.</p>',
	'info_connexion_mysql' => 'Połączenie z bazą SQL',
	'info_connexion_ok' => 'Połączenie powiodło się.',
	'info_contact' => 'Kontakt',
	'info_contenu_articles' => 'Tematyka artykułów',
	'info_contributions' => 'Wkład',
	'info_creation_paragraphe' => 'By utworzyć akapity, po prostu zostaw puste linijki.',
	'info_creation_rubrique' => 'Aby móc pisać artykuły,<br /> musisz utworzyć przynajmniej jeden dział.<br />',
	'info_creation_tables' => 'Tworzenie tablic bazy danych',
	'info_creer_base' => '<b>Utwórz</b> nową bazę danych :',
	'info_dans_rubrique' => 'W dziale:',
	'info_date_publication_anterieure' => 'Data poprzedniej publikacji:',
	'info_date_referencement' => 'DATA ZLINKOWANIA TEJ STRONY:',
	'info_derniere_etape' => 'Zakończone z sukcesem!',
	'info_descriptif' => 'Opis:',
	'info_desinstaller_plugin' => 'usuń dane i wyłącz plugina',
	'info_discussion_cours' => 'Dyskusja w toku',
	'info_ecrire_article' => 'Aby móc pisać artykuły, musisz utworzyć przynajmniej jeden dział.',
	'info_email_envoi' => 'Adres e-mail nadawcy (nieobowiązkowo)',
	'info_email_envoi_txt' => 'Wpisz adres e-maila, który będzie używany do wywyłania wiadomości (domyślnie adres odbiorcy będzie jednocześnie adresem wysyłkowym) :',
	'info_email_webmestre' => 'Adres e-mail webmastera', # MODIF
	'info_envoi_email_automatique' => 'Automatyczna wysyłka maili',
	'info_envoyer_maintenant' => 'Wyślij teraz',
	'info_etape_suivante' => 'Przejdź do następnego kroku',
	'info_etape_suivante_1' => 'Możesz przejść do następnego kroku.',
	'info_etape_suivante_2' => 'Możesz przejść do następnego kroku.',
	'info_exceptions_proxy' => 'Wyjątki dla pełnomocnika',
	'info_exportation_base' => 'eksportuj bazę danych do @archive@',
	'info_facilite_suivi_activite' => 'W celu uproszczenia działań
  redakcyjnych strony, SPIP może wysłać mailem, na przykład
   na listę mailingową redaktorów, informację-zapytanie
  o sprawdzenie i publikację artykułów.', # MODIF
	'info_fichiers_authent' => 'Plik uwierzytelniający « .htpasswd »',
	'info_forums_abo_invites' => 'Twoja strona zawiera formularze dostępne po zalogowaniu, zatem odwiedzający powinni się zarejestrować na stronie publicznej.', # MODIF
	'info_gauche_admin_tech' => 'Ta strona jest dostępna tylko dla osób kierujących witryną.</b><p>
Daje dostęp do różnych funkcje konserwacji technicznej. Niektóre spośród nich wymagają specjalnego uwierzytelnienia, które można uzyskać jedynie poprzez FTP.</p>',
	'info_gauche_auteurs' => 'Znajdziesz tutaj informacje o wszystkich autorach serwisu.
 Ich kompetencje są zaznaczone kolorem ikony (redaktor = zielonym; administrator = żółtym).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Autorzy zewnętrzni, bez dostępu do strefy publicznej, są zaznaczeni niebieską ikoną ;
  autorzy skasowani szarą ikoną.',
	'info_gauche_messagerie' => 'Poczta wewnętrzna pozwala Ci wymieniać wiadomości z innymi redaktorami, i zapisywać notki (prywatne) lub publikować ogłoszenia na stronie głównej strefy prywatnej (jeśli jesteś administratorem).', # MODIF
	'info_gauche_statistiques_referers' => 'Ta strona wyświetla listę <i>odnośników</i>, to znaczy stron które zawierają łącza prowadzące do Twojej strony, które ktoś użył wczoraj lub dzisiaj : lista jest zerowana co 24 godziny.',
	'info_gauche_visiteurs_enregistres' => 'Znajdziesz tu gości zarejestrowanych
 w strefie publicznej strony (abonament forum).',
	'info_generation_miniatures_images' => 'Generowanie miniaturek obrazków',
	'info_gerer_trad_objets' => '@objets@ : zarządzać linkami do tłumaczenia', # RELIRE
	'info_hebergeur_desactiver_envoi_email' => 'Niektóre serwisy hostingowe wyłączają możliwość automatycznego wywyłania
  emaili za pośrednictwem ich serwerów. W tym przypadku te funkcje
  SPIP nie będą działały.',
	'info_hier' => 'wczoraj:',
	'info_identification_publique' => 'Twoja nazwa publiczna',
	'info_image_process' => 'Wybierz najlepsza metode przygotowania miniaturek kilkając na odpowiednim obrazku.',
	'info_image_process2' => 'Jeśli nie wyświetlił się żaden obrazek, to twój serwer nie został skonfugurowany tak, aby skorzystać z tego narzędzia. Jeśli jednak chcesz skorzystać z tych funkcji, skontaktuj się z osobą odpowiedzialną za sprawy techniczne twojego serwisu i poproś o włączenie rozszerzeń "GD" lub "Imagick".',
	'info_images_auto' => 'Automatycznie obliczane rozmiary obrazka',
	'info_informations_personnelles' => 'Informacje o użytkowniku',
	'info_inscription' => 'Zarejestrowany dnia :', # RELIRE
	'info_inscription_automatique' => 'Automatyczna rejestracja nowych redaktorów', # MODIF
	'info_jeu_caractere' => 'Kodowanie strony',
	'info_jours' => 'dni',
	'info_laisser_champs_vides' => 'pozostaw te pola puste)',
	'info_langues' => 'Języki stron',
	'info_ldap_ok' => 'Uwierzytelnianie LDAP jest włączone.',
	'info_lien_hypertexte' => 'Hiperłącze:',
	'info_liste_nouveautes_envoyee' => 'Lista aktualizacji wiadomości została wysłana',
	'info_liste_redacteurs_connectes' => 'Lista zalogowanych redaktorów', # MODIF
	'info_login_existant' => 'Podany login już istnieje.',
	'info_login_trop_court' => 'Za krótki login.',
	'info_login_trop_court_car_pluriel' => 'Twój login musi zawierać przynajmniej @nb@ znaków.',
	'info_logos' => 'Logo',
	'info_maximum' => 'maksimum:',
	'info_meme_rubrique' => 'W tym samym dziale',
	'info_message_en_redaction' => 'Twoje wiadomości w trakcie tworzenia',
	'info_message_technique' => 'Wiadomość techniczna:',
	'info_messagerie_interne' => 'Poczta wewnętrzna',
	'info_mise_a_niveau_base' => 'uaktualnianie bazy SQL',
	'info_mise_a_niveau_base_2' => '{{Uwaga !}} Zainstalowałeś taką wersję
  plików SPIP, które należą do wcześniejszej niż posiadana przez ciebie wersja:
  twoja baza danych może zostać zniszczona
  lub popsuta i strona przestanie działać.<br />{{Zainstaluj ponownie
  pliki SPIP.}}',
	'info_modification_enregistree' => 'Twoje zmiany zostały zapisane',
	'info_modifier_auteur' => 'Edytuj dane autora:',
	'info_modifier_rubrique' => 'Zmiana działu:',
	'info_modifier_titre' => 'Zmiana: @titre@',
	'info_mon_site_spip' => 'Moja strona SPIP',
	'info_moyenne' => 'średnia:',
	'info_multi_cet_article' => 'Język tego artykułu:',
	'info_multi_langues_choisies' => 'Wybierz języki do dyspozycji redaktorów twojej strony.
  Języki już używane na twojej stronie(wyświetlane na początku) nie mogą być wyłączone.', # MODIF
	'info_multi_objets' => '@objets@ : aktywować menu językowe', # RELIRE
	'info_multi_secteurs' => ' ... tylko dla działów podstawowych ?',
	'info_nb_articles' => '@nb@ artykuły',
	'info_nb_auteurs' => '@nb@ autorzy',
	'info_nb_messages' => '@nb@ wiadomości',
	'info_nb_mots_cles' => '@nb@ słów kluczowych',
	'info_nb_rubriques' => '@nb@ działow', # RELIRE
	'info_nb_visiteurs' => '@nb@ goście',
	'info_nom' => 'Nazwisko',
	'info_nom_destinataire' => 'Nazwisko odbiorcy',
	'info_nom_pas_conforme' => 'Tagi html nie są dozwolone',
	'info_nom_site' => 'Nazwa Twojej strony',
	'info_nombre_articles' => '@nb_articles@ artykułów,',
	'info_nombre_rubriques' => '@nb_rubriques@ dzialów,',
	'info_nombre_sites' => '@nb_sites@ stron,',
	'info_non_deplacer' => 'Nie zmieniać miejsca ...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP może regularnie wysyłać ogłoszenia o najnowszych newsach.
  (ostatnio opublikowane artykuły i newsy).',
	'info_non_envoi_liste_nouveautes' => 'Nie wysyłaj listy najnowszych newsów',
	'info_non_modifiable' => 'nie może być zmienione',
	'info_non_suppression_mot_cle' => 'Nie chcę usunąć tego słowa kluczowego.',
	'info_notes' => 'Notatki',
	'info_nouvel_article' => 'Nowy artykuł',
	'info_nouvelle_traduction' => 'Nowe tłumaczenie:',
	'info_numero_article' => 'ARTYKUŁ NUMER:',
	'info_obligatoire_02' => '(obowiązkowo)', # MODIF
	'info_option_accepter_visiteurs' => 'Zaakceptuj zapisy czytelników Twojej strony', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Wyłącz zapisy czytelników serwisu', # MODIF
	'info_options_avancees' => 'OPCJE ZAAWANSOWANE',
	'info_ou' => 'lub...',
	'info_page_interdite' => 'Strona zabroniona',
	'info_par_nom' => 'wg nazw',
	'info_par_nombre_article' => '(wg liczby artykułów)',
	'info_par_statut' => 'wg statusu',
	'info_par_tri' => '’(według @tri@)’',
	'info_passe_trop_court' => 'Za krótkie hasło.',
	'info_passe_trop_court_car_pluriel' => 'Hasło musi zawierać co najmniej @nb@ znaków.', # RELIRE
	'info_passes_identiques' => 'Hasła nie są identyczne.',
	'info_plus_cinq_car' => 'więcej niż 5 znaków',
	'info_plus_cinq_car_2' => '(Więcej niż 5 znaków)',
	'info_plus_trois_car' => '(Więcej niż 3 znaki)',
	'info_popularite' => 'popularność: @popularite@; odwiedziny: @visites@',
	'info_post_scriptum' => 'Postscriptum',
	'info_post_scriptum_2' => 'Postscriptum:',
	'info_pour' => 'dla',
	'info_preview_texte' => 'Istnieje możliwość włączania podglądu nieopublikowanych artykułów i newsów (muszą być "zaproponowane do oceny"). Czy chcesz, żeby ta funkcja była dostępna dla administratorów, redaktorów czy dla nikogo? ', # MODIF
	'info_procedez_par_etape' => 'Postępuj krok po kroku',
	'info_procedure_maj_version' => 'powinna zostać procedura uaktualniania w celu dostosowania
 bazy danych do nowej wersji SPIP.',
	'info_proxy_ok' => 'Test proxy udany.',
	'info_ps' => 'P.S.',
	'info_publier' => 'opublikuj',
	'info_publies' => 'Twoje artykuły opublikowane online',
	'info_question_accepter_visiteurs' => 'Jeśli szkielety Twojego serwisu przewidują dla odwiedzających zapisy bez dostępu do panelu administracyjnego, włącz poniższą opcję:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Czy akceptujesz rejestracje nowych redaktorów za pośrednictwem strony publicznej? Jeśli tak, odwiedzający będą mogli się zapisać za pomocą zautomatyzowanego formularza i będą mieli dostęp do strefy prywatnej, gdzie będą proponować własne artykuły. <div class="notice">W trakcie procesu zapisywania,  użytkownik otrzyma automatycznie mailem  hasła dostępu do strefy prywatnej. Niektóre serwisy hostingowe wyłączają możliwość wysyłania maili z ich  serwerów : w tym przypadku automatyczne zapisanie się jest niemożliwe.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ pracował nad tą treścią @date_diff@ minut temu.',
	'info_racine_site' => 'Katalog główny',
	'info_recharger_page' => 'Proszę za chwilę ponownie załadować tę stronę.',
	'info_recherche_auteur_zero' => '<b>Żadnych wyników dla " @cherche_auteur@ ".',
	'info_recommencer' => 'Proszę spróbować ponownie.',
	'info_redacteur_1' => 'Redaktor',
	'info_redacteur_2' => 'posiadając dostęp do strefy prywatnej (<i>zaleca się</i>)',
	'info_redacteurs' => 'Redaktorzy',
	'info_redaction_en_cours' => 'REDAKCJA W TOKU',
	'info_redirection' => 'Przekierowanie',
	'info_redirection_activee' => 'Przekierowanie jest aktywne.',
	'info_redirection_boucle' => 'Próbujesz przekierować ten artykuł do samego siebie.',
	'info_redirection_desactivee' => 'Przekierowanie zostało usunięte.',
	'info_refuses' => 'Twoje odrzucone artykuły',
	'info_reglage_ldap' => 'Opcje: <b>Regulacja importu LDAP</b>',
	'info_renvoi_article' => '<b>Przekierowanie.</b> Ten artykuł odsyła do strony:',
	'info_reserve_admin' => 'Tylko administratorzy mogą zmienić ten adres.', # MODIF
	'info_restreindre_rubrique' => 'Ograniczenie zarządzaniem rubryką :',
	'info_resultat_recherche' => 'Wyniki wyszukiwania:',
	'info_rubriques' => 'Działy',
	'info_rubriques_02' => 'działy',
	'info_rubriques_trouvees' => 'Odnalezione działy',
	'info_sans_titre' => 'Bez tytułu',
	'info_selection_chemin_acces' => '<b>Wybierz</b> poniżej ścieżkę dostępu w katalogu:',
	'info_signatures' => 'podpisy',
	'info_site' => 'Strona',
	'info_site_2' => 'strona:',
	'info_site_min' => 'strona',
	'info_site_reference_2' => 'Strona zlinkowana',
	'info_site_web' => 'Strona internetowa:',
	'info_sites' => 'strony',
	'info_sites_lies_mot' => 'Zlinkowane strony związane z tymi słowami kluczowymi',
	'info_sites_proxy' => 'Użyj proxy',
	'info_sites_trouves' => 'Znalezione strony',
	'info_sous_titre' => 'Podtytuł:',
	'info_statut_administrateur' => 'Administrator', # MODIF
	'info_statut_auteur' => 'Status tego autora:',
	'info_statut_auteur_2' => 'Jestem',
	'info_statut_auteur_a_confirmer' => 'Potwierdzenie subskrypcji',
	'info_statut_auteur_autre' => 'Inny status :',
	'info_statut_redacteur' => 'Redaktor',
	'info_statut_utilisateurs_1' => 'Domyślny status zaiportowanych użytkowników', # MODIF
	'info_statut_utilisateurs_2' => 'Wybierz status, który zostanie przyznany osobom występującym w katalogu LDAP, kiedy połączą się po raz pierwszy. Możesz zmieniać tę wartość w zależności od autora. ', # MODIF
	'info_suivi_activite' => 'Archiwum aktywności edytorskiej',
	'info_surtitre' => 'Nadtytuł :',
	'info_syndication_integrale_1' => 'Twoja strona oferuje plik syndykacji « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Czy chcesz przesyłać całe artykuły czy wolisz dystrybuować podsumowanie ograniczone do kilkuset znaków ?',
	'info_table_prefix' => 'Możesz użyć własnego prefixa nazw tablic w bazie danych (jest to niezbędne jeśli chcesz zainstalować więcej stron przy użyciu tej samej bazy danych). Prefix powinien być pisany bez akcentów, małymi literami i bez spacji.',
	'info_taille_maximale_images' => 'SPIP przetestuje maksymalny rozmiar obrazów, które może przetwarzać (w milionach pikseli). <br /> Większe obrazy nie zostaną zmniejszone.', # RELIRE
	'info_taille_maximale_vignette' => 'Maksymalny rozmiar minitaurek, generowanych przez system :',
	'info_terminer_installation' => 'Możesz teraz zakończyć proces standardowej instalacji.',
	'info_texte' => 'Tekst',
	'info_texte_explicatif' => 'Tekst wyjaśniający',
	'info_texte_long' => '(tekst jest za długi: pojawi się w kilku częściach, które zostaną złożone po zatwierdzeniu.)',
	'info_texte_message' => 'Tekst Twojej wiadomości',
	'info_texte_message_02' => 'Tekst wiadomości',
	'info_titre' => 'Tytuł:',
	'info_total' => 'ogółem:',
	'info_tous_articles_en_redaction' => 'Wszystkie artykuły w toku',
	'info_tous_articles_presents' => 'Wszystkie artykuły opublikowane w tym dziale',
	'info_tous_articles_refuses' => 'Wszystkie odrzucone teksty',
	'info_tous_les' => 'każdy:',
	'info_tout_site' => 'Cała strona',
	'info_tout_site2' => 'Artykuł nie został jeszcze przetłumaczony na ten język.',
	'info_tout_site3' => 'Artykuł został przetłumaczony na ten język, ale po dokonaniu przekładu zostały wprowadzone zmiany do artykułu źródłowego. Przekład powinien zostać uaktualniony.',
	'info_tout_site4' => 'Artykuł został przetłumaczony na ten język i nie wymaga uaktualniania.',
	'info_tout_site5' => 'Artykuł oryginalny.',
	'info_tout_site6' => '<b>Uwaga :</b> wyświetlone zostały jedynie artykuły oryginalne.
Przekłady są połączone z oryginałem, za pomocą koloru wskazującego na ich status :',
	'info_traductions' => 'Tłumaczenia',
	'info_travail_colaboratif' => 'Praca zespołowa nad artykułem',
	'info_un_article' => 'artykuł,',
	'info_un_site' => 'strona,',
	'info_une_rubrique' => 'dział,',
	'info_une_rubrique_02' => '1 dział',
	'info_url' => 'URL:',
	'info_url_proxy' => 'Adres URL serwera proxy',
	'info_url_proxy_pas_conforme' => 'Adres URL serwera proxy jest nieprawidłowy.',
	'info_url_site_pas_conforme' => 'Adres URL witryny jest nieprawidłowy.', # RELIRE
	'info_url_test_proxy' => 'URL testowy', # RELIRE
	'info_urlref' => 'Łącze hipertekstowe :',
	'info_utilisation_spip' => 'SPIP jest już gotowy do użytku...',
	'info_visites_par_mois' => 'Wizyt miesięcznie:',
	'info_visiteur_1' => 'Odwiedzający',
	'info_visiteur_2' => 'strony publicznej',
	'info_visiteurs' => 'Odwiedzający',
	'info_visiteurs_02' => 'Odwiedzający stronę publiczną',
	'info_webmestre_forces' => 'Webmasterzy są obecnie zdefiniowani w <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Adres bazy danych przyznany przez usługodawcę hostingowego',
	'install_connect_ok' => 'Nowa baza danych została zadeklarowana pod nazwą serwera @connect@.', # RELIRE
	'install_echec_annonce' => 'Instalacja może się nie powieść lub może się zdażyć, że strona przestanie działać ...',
	'install_extension_mbstring' => 'SPIP nie działa z:',
	'install_extension_php_obligatoire' => 'SPIP wymaga rozszerzenia php:',
	'install_login_base_hebergeur' => 'Login połączenia z bazą danych przyznany przez usługodawcę hostingowego',
	'install_nom_base_hebergeur' => 'Nazwa bazy danych przyznana przez usługodawcę hostingowego:',
	'install_pas_table' => 'Bazy danych nie ma tabel',
	'install_pass_base_hebergeur' => 'Hasło do bazy danych przyznane przez usługodawcę hostingowego',
	'install_php_version' => 'wersja PHP @version@ jest za niska (minimum = @minimum@)',
	'install_select_langue' => 'Wybierz język i kliknij na przycisk "next" aby rozpocząć procedurę instalacji.',
	'install_select_type_db' => 'Wskaż rodzaj bazy danych:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Serwer bazy danych został przypisny przez dostawcę usług hostingowych.',
	'install_table_prefix_hebergeur' => 'Prefix przyznany przez usługodawcę hostingowego',
	'install_tables_base' => 'Tabele w bazie danych',
	'install_types_db_connus' => 'SPIP może używać <b>MySQL</b> (najczęstszy) oraz <b>SQLite</b>.', # RELIRE
	'install_types_db_connus_avertissement' => 'Wsparcie <b>PostgreSQL</b> jest również dostępne na zasadzie eksperymentu.', # RELIRE
	'instituer_erreur_statut_a_change' => 'Status został już zmodyfikowany',
	'instituer_erreur_statut_non_autorise' => 'Nie możesz wybrać tego statusu',
	'intem_redacteur' => 'redaktorem',
	'intitule_licence' => 'Licencja',
	'item_accepter_inscriptions' => 'Zaakceptuj zapisy',
	'item_activer_messages_avertissement' => 'Aktywuj komunikaty ostrzegawcze',
	'item_administrateur_2' => 'administratorem', # MODIF
	'item_afficher_calendrier' => 'Wyświetl kalendarz',
	'item_autoriser_syndication_integrale' => 'Wysyłanie pełnej treści artykułów w pliku syndykacji',
	'item_choix_administrateurs' => 'administratorzy', # MODIF
	'item_choix_generation_miniature' => 'Generuj automatycznie miniaturki obrazków.',
	'item_choix_non_generation_miniature' => 'Nie generuj miniaturek obrazków.',
	'item_choix_redacteurs' => 'redaktorzy',
	'item_choix_visiteurs' => 'odwiedzający stronę publiczną',
	'item_creer_fichiers_authent' => 'Utwórz pliki .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Aktywuj system wiadomości i kalendarzy',
	'item_mots_cles_association_articles' => 'artykuły',
	'item_mots_cles_association_rubriques' => 'do działów',
	'item_mots_cles_association_sites' => 'do stron zlinkowanych lub zrzeszonych.',
	'item_non' => 'Nie',
	'item_non_accepter_inscriptions' => 'Nie akceptuj zapisów',
	'item_non_activer_messages_avertissement' => 'Wyłącz komunikaty ostrzeżeń',
	'item_non_afficher_calendrier' => 'Nie wyświetlaj kalendarza',
	'item_non_autoriser_syndication_integrale' => 'Wysyłanie podsumowania',
	'item_non_creer_fichiers_authent' => 'Nie twórz tych plików',
	'item_non_messagerie_agenda' => 'Wyłącz system komunikacji i kalendarze oprogramowania',
	'item_non_publier_articles' => 'Nie publikuj artykułów przed datą ich publikacji.',
	'item_nouvel_auteur' => 'Nowy autor',
	'item_nouvelle_rubrique' => 'Nowy dział',
	'item_oui' => 'Tak',
	'item_publier_articles' => 'Publikuj artykuły bez względu na datę ich publikacji.',
	'item_reponse_article' => 'Odpowiedz na artykuł',
	'item_visiteur' => 'odwiedzający',

	// J
	'jour_non_connu_nc' => 'nieznany',

	// L
	'label_bando_outils' => 'Pasek narzędzi',
	'label_bando_outils_afficher' => 'Pokaż narzedzia',
	'label_bando_outils_masquer' => 'Ukryj narzędzia',
	'label_choix_langue' => 'Wybierz swój język',
	'label_nom_fichier_connect' => 'Podaj nazwę dla tego serwera',
	'label_slogan_site' => 'Slogan witryny internetowej',
	'label_taille_ecran' => 'Szerokość ekranu',
	'label_texte_et_icones_navigation' => 'Menu nawigacyjne',
	'label_texte_et_icones_page' => 'Wyświetlanie stron',
	'ldap_correspondance' => 'dziedziczy z pola @champ@', # RELIRE
	'ldap_correspondance_1' => 'dziedziczy z pól LDAP', # RELIRE
	'ldap_correspondance_2' => 'Dla każdego z poniższych pól SPIP należy podać nazwę odpowiedniego pola LDAP. Pozostaw puste, aby je nie wypełnić, oddziel je spacjami lub przecinkami, aby wypróbować wiele pól LDAP.', # RELIRE
	'lien_ajouter_auteur' => 'Dodaj autora',
	'lien_ajouter_une_rubrique' => 'Dodaj tą sekcję',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NAZWA STRONY:',
	'lien_rapide_contenu' => 'Idź do treści',
	'lien_rapide_navigation' => 'Idź do menu',
	'lien_rapide_recherche' => 'Idź do wyszukiwania', # RELIRE
	'lien_retirer_auteur' => 'Usuń autora',
	'lien_retirer_rubrique' => 'Usuń sekcję',
	'lien_retirer_tous_auteurs' => 'Usuń wszystkich autorów',
	'lien_retirer_toutes_rubriques' => 'Usuń wszystkie sekcje',
	'lien_site' => 'strona',
	'lien_tout_decocher' => 'Odznacz wszystko',
	'lien_tout_deplier' => 'Zwiń wszystko',
	'lien_tout_replier' => 'Rozwiń wszystko',
	'lien_tout_supprimer' => 'Usuń wszystko',
	'lien_trier_nom' => 'Sortuj według nazw',
	'lien_trier_nombre_articles' => 'Sortuj według liczby artykułów',
	'lien_trier_statut' => 'Sortuj według status',
	'lien_voir_en_ligne' => 'ZOBACZ ON-LINE :',
	'logo_article' => 'Logo artykułu',
	'logo_auteur' => 'Logo autora',
	'logo_rubrique' => 'Logo działu',
	'logo_site' => 'Logo strony',
	'logo_standard_rubrique' => 'Standardowe logo dla działow',
	'logo_survol' => 'Logo po najechaniu kursorem',

	// M
	'menu_aide_installation_choix_base' => 'Wybieranie bazy danych',
	'module_fichier_langue' => 'Plik językowy',
	'module_raccourci' => 'Skrót',
	'module_texte_affiche' => 'Wyświetlany tekst',
	'module_texte_explicatif' => 'Możesz umieścić następujące skróty w szkielecie Twojej strony publicznej. Zostaną automatycznie przetłumaczone na rózne języki, których pliki językowe istnieją.',
	'module_texte_traduction' => 'Plik językowy « @module@ » jest dostępny w :',
	'mois_non_connu' => 'nieznany',

	// N
	'nouvelle_version_spip' => 'Aktualizacja SPIP do wersji @version@ jest dostępna',
	'nouvelle_version_spip_majeure' => 'Nowa wersja SPIP (@version@) jest dostępna',

	// O
	'onglet_contenu' => 'Treść',
	'onglet_declarer_une_autre_base' => 'Oświadcz inną bazę danych',
	'onglet_discuter' => 'Dyskutuj',
	'onglet_interactivite' => 'Interaktywacja',
	'onglet_proprietes' => 'Właściwości',
	'onglet_repartition_actuelle' => 'teraz',
	'onglet_sous_rubriques' => 'Podsekcje',

	// P
	'page_pas_proxy' => 'Ta strona nie musi przejść przez pełnomocnika.',
	'pas_de_proxy_pour' => 'Jeśli potrzeba podaj serwery lub domeny, do których to proxy ma nie być używane: @exemple@)',
	'phpinfo' => 'Ustawienia PHP',
	'plugin_charge_paquet' => 'Ładowanie archiwum @name@',
	'plugin_charger' => 'pobierz pliki z serwera',
	'plugin_erreur_charger' => 'błąd : nie można pobrać pliku @zip@',
	'plugin_erreur_droit1' => 'Katalog <code>@dest@</code> nie jest zapisywalny.', # RELIRE
	'plugin_erreur_droit2' => 'Proszę sprawdzić uprawnienia do zapisu w tym katalogu (i utworzenia katalogu, jeśli to konieczne). Ewentualnie proszę zainstalować pliki przez FTP.',
	'plugin_erreur_zip' => 'Problem z pclzip : błąd @status@',
	'plugin_etat_developpement' => 'wersja rozwojowa',
	'plugin_etat_experimental' => 'wersja eksperymentalna',
	'plugin_etat_stable' => 'wersja stabilna',
	'plugin_etat_test' => 'wersja testowa',
	'plugin_impossible_activer' => 'Nie można włączyć plugina @plugin@',
	'plugin_info_automatique1' => 'Jeśli chcesz umożliwić automatyczną instalację wtyczek, prosimy:',
	'plugin_info_automatique1_lib' => 'Jeśli chcesz, aby ta biblioteka została zainstalowana automatycznie, należy:',
	'plugin_info_automatique2' => 'Utwórz katalog <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Upewnij się że serwer ma odpowiednie uprawnienia do zapisu w tym katalogu.',
	'plugin_info_automatique_creer' => 'Utworzyć w katalogu głównym witryny.',
	'plugin_info_automatique_exemples' => 'przykłady:',
	'plugin_info_automatique_ftp' => 'Możesz zainstalować wtyczki przez FTP, korzystając z folderu <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Niektóre wtyczki wymagają możliwości wrzucania plików do folderu <code>lib/</code>. Folder ten powinien zostać utworzony w root.',
	'plugin_info_automatique_liste' => 'Twoje listy wtyczek:',
	'plugin_info_automatique_liste_officielle' => 'Oficjalne pluginy',
	'plugin_info_automatique_liste_update' => 'Aktualizacja list',
	'plugin_info_automatique_ou' => 'albo...',
	'plugin_info_automatique_select' => 'Wybierz wtyczkę poniżej: SPIP pobierze ją i zainstaluje w katalogu <code>@rep@</code>; Jeśli ta wtyczka już istnieje, zostanie zaktualizowana.', # RELIRE
	'plugin_info_credit' => 'Kredyty',
	'plugin_info_erreur_xml' => 'Nieprawidłowe zgłoszenie wtyczek',
	'plugin_info_install_ok' => 'Instalacja się udała',
	'plugin_info_necessite' => 'Wymaga:',
	'plugin_info_non_compatible_spip' => 'Ta wtyczka jest niezgodny z tą wersją systemu SPIP',
	'plugin_info_plugins_dist_1' => 'Następujące wtyczki są załadowane i uruchomione w katalogu @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Nie mogą zostać wyłączone.',
	'plugin_info_telecharger' => 'pobrać z @url@ i zainstalować w @rep@',
	'plugin_info_upgrade_ok' => 'Aktualizacja udana', # RELIRE
	'plugin_librairies_installees' => 'Biblioteka programistyczna została zainstalowana',
	'plugin_necessite_extension_php' => 'Wymaga rozszerzenia PHP @plugin@ w wersji @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Wymaga rozszerzenia PHP @plugin@',
	'plugin_necessite_lib' => 'Ta wtyczka wymaga biblioteki programistycznej @lib@',
	'plugin_necessite_php' => 'Wymaga @plugin@ w wersji @version@.',
	'plugin_necessite_plugin' => 'Potrzeba pluginu @plugin@ w wersji @version@.',
	'plugin_necessite_plugin_sans_version' => 'Wymaga wtyczki @plugin@',
	'plugin_necessite_spip' => 'Potrzeba co minimum wersji SPIP @version@ .',
	'plugin_source' => 'źródło:',
	'plugin_titre_automatique' => 'Instalacja automatyczna ',
	'plugin_titre_automatique_ajouter' => 'Dodaj wtyczki',
	'plugin_titre_installation' => 'Instalacja wtyczki @plugin@',
	'plugin_titre_modifier' => 'Moje wtyczki',
	'plugin_utilise_extension_php' => 'Używa rozszerzenia PHP @plugin@ w wersji @version@.', # MODIF
	'plugin_utilise_plugin' => 'Używa wtyczki @plugin@ w wersji @version@.', # MODIF
	'plugin_zip_active' => 'Kontynuuj w celu aktywacji',
	'plugin_zip_adresse' => 'Aby załadować spakowany plik wtyczki lub listę wtyczek, wprowadź ścieżkę poniżej.',
	'plugin_zip_adresse_champ' => 'Ścieżka wtyczki lub listy',
	'plugin_zip_content' => 'Zawiera następujące pliki (@taille@), <br /> gotowe do zainstalowania w katalogu <code>@rep@</ code>', # RELIRE
	'plugin_zip_installe_finie' => 'Plik @zip@ został rozpakowany i zainstalowany.',
	'plugin_zip_installe_rep_finie' => 'Plik @zip@ został rozpakowany i zainstalowany w katalogu @rep@ ',
	'plugin_zip_installer' => 'Teraz możesz to zainstalować.',
	'plugin_zip_telecharge' => 'Plik @zip@ został załadowany',
	'plugins_actif_aucun' => 'Żadna wtyczka nie jest aktywna.',
	'plugins_actif_un' => 'Jedna aktywna wtyczka.',
	'plugins_actifs' => '@count@ aktywnych wtyczek.',
	'plugins_actifs_liste' => 'Włączone',
	'plugins_compte' => '@count@ wtyczek',
	'plugins_disponible_un' => 'Jedna wtyczka dostępna',
	'plugins_disponibles' => '@count@ dostępnych wtyczek.',
	'plugins_erreur' => 'Błąd w wtyczkach : @plugins@',
	'plugins_liste' => 'Lista rozszerzeń',
	'plugins_liste_dist' => 'Zablokowane wtyczki', # RELIRE
	'plugins_recents' => 'Ostatnie wtyczki.',
	'plugins_tous_liste' => 'Wszystko',
	'plugins_vue_hierarchie' => 'Hierarchia',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Wersja protokołu:',

	// Q
	'queue_executer_maintenant' => 'Uruchom teraz',
	'queue_info_purger' => 'Możesz usunąć wszystkie zadania w toku i zresetować listę zadań okresowych', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ zadania w kolejce', # MODIF
	'queue_next_job_in_nb_sec' => 'Następne zadanie w @nb@ S', # MODIF
	'queue_no_job_in_queue' => 'Brak zadań w toku', # MODIF
	'queue_one_job_in_queue' => '1 zadanie w kolejce', # MODIF
	'queue_purger_queue' => 'Zresetuj kolejkę zadań', # MODIF
	'queue_titre' => 'Lista zadań', # MODIF

	// R
	'repertoire_plugins' => 'Katalog :',
	'required' => '(Obowiązkowo)', # MODIF

	// S
	'sans_heure' => 'Czas nie określony',
	'statut_admin_restreint' => 'admin z ograniczeniami',
	'statut_webmestre' => 'webmaster',

	// T
	'tache_cron_asap' => 'Zadanie CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Zadanie CRON @function@ (co @nb@ s)', # RELIRE
	'taille_cache_image' => 'Obrazki mają automatycznie zmieniany rozmiar przez SPIP (miniaturki dokumentów, tytuły przedstawiane w postaci graficznej, funkcje matematyczne w formacie TeX...) zajmują w katalogu @dir@ obszar @taille@.',
	'taille_cache_moins_de' => 'Rozmiar pamięci podręcznej jest mniejsze niż @octets@.',
	'taille_cache_octets' => 'Rozmiar pamięci podręcznej wynosi obecnie około @octets@.',
	'taille_cache_vide' => 'Cache jest pusty.',
	'taille_repertoire_cache' => 'Wielkość katalogu cache',
	'text_article_propose_publication' => 'Artykuł zatwierdzony do publikacji. ',
	'texte_acces_ldap_anonyme_1' => 'Niektóre serwery LDAP nie akceptują dostępu anonimowego. W tym przypadku należy podać indentyfikator dostępu, aby móc przeszukiwać katalog. Niemniej, w większości przypadków poniższe pola powinny pozostać puste.',
	'texte_admin_effacer_01' => 'Ta komenda usuwa <i>całą</i> zawartość bazy danych,
włącznie z <i>wszystkimi</i> parametrami dostępu dla redaktorów i administartorów. Po jej zastosowaniu powinieneś
zreinstalować SPIP w celu utworzenia nowej bazy danych i dostępu pierwszego administratora.', # MODIF
	'texte_adresse_annuaire_1' => '(Jeśli Twój katalog jest zainstalowany na tym samym komputerze co strona internetowa, chodzi zapewne o «localhost».)',
	'texte_ajout_auteur' => 'Następujący autor został dodany do artykułu:',
	'texte_annuaire_ldap_1' => 'Jeśli masz dostęp do katalogu (LDAP), możesz zniego skorzystać do automatycznego importu użytkowników SPIP.  ', # MODIF
	'texte_article_statut' => 'Ten artykuł jest:',
	'texte_article_virtuel' => 'Wirtualny artykuł',
	'texte_article_virtuel_reference' => '<b>Artykuł wirtualny :</b> artykuł zlinkowany w Twoim serwisie SPIP ale przekierowujący do innego URL-a. Aby usunąć to przekierowanie, wymaż URL powyżej.',
	'texte_aucun_resultat_auteur' => 'Żadnych wyników dla "@cherche_auteur@".',
	'texte_auteur_messagerie' => 'Na tej stronie może wyświetlać się bez przerwy lista zalogowanych redaktorów, co pozwoli Ci bezpośrednio wymieniać z nimi wiadomości. Możesz także zdecydować o nie pojawianiu się na tej liście (jesteś wówczas "niewidzialny" dla innych użytkowników)', # MODIF
	'texte_auteurs' => 'AUTORZY',
	'texte_choix_base_1' => 'Wybierz bazę danych:',
	'texte_choix_base_2' => 'Serwer SQL zawiera kilka baz danych.',
	'texte_choix_base_3' => '<b>Wybierz</b>, jaka została Ci przyznana przez Twój serwis hostingowy:',
	'texte_choix_table_prefix' => 'Prefix tablic:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elementy',
	'texte_conflit_edition_correction' => 'Proszę porównać różnice między obiema wersjami. Możesz również skopiować zmiany i zacząć od nowa.',
	'texte_connexion_mysql' => 'Sprawdź informacje dostarczone przez hosta: powinieneś znaleźć oferowany serwer bazy danych i swoje osobiste poświadczenia, aby się z nim połączyć.',
	'texte_contenu_article' => '(Treść artykułu w kilku słowach.)',
	'texte_contenu_articles' => 'Zależnie od struktury jaką przyjąłeś dla swojego serwisu, możesz zdecydować,
 których elementów artykułów nie używać.Korzystając z poniższej listy, wybierz używane elementy.',
	'texte_crash_base' => 'Jeśli Twoja baza danych
   zepsuła, możesz spróbować naprawić ją
   automatycznie.',
	'texte_creer_rubrique' => 'Aby móc pisać artykuły,<br /> musisz utworzyć dział.',
	'texte_date_creation_article' => 'DATA UTWORZENIA ARTYKUŁU:',
	'texte_date_creation_objet' => 'Data utworzenia:', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Data poprzedniej publikacji :',
	'texte_date_publication_anterieure_nonaffichee' => 'Ukryj datę poprzedniej publikacji.',
	'texte_date_publication_article' => 'DATA PUBLIKACJI ONLINE:',
	'texte_date_publication_objet' => 'Opublikowane na:',
	'texte_definir_comme_traduction_rubrique' => 'Ta sekcja jest tłumaczeniem sekcji numer:',
	'texte_descriptif_rapide' => 'Krótki opis',
	'texte_effacer_base' => 'Usuń bazę danych SPIP',
	'texte_effacer_statistiques' => 'Usuń statystyki',
	'texte_en_cours_validation' => 'Poniższe treści oczekują na sprawdzenie.',
	'texte_enrichir_mise_a_jour' => 'Możesz wzbogacić układ Twojego tekstu « skrótami typograficznymi ».',
	'texte_fichier_authent' => '<b>Czy SPIP ma stworzyć specjalne pliki <tt>.htpasswd</tt>  i <tt>.htpasswd-admin</tt> w katalogu @dossier@?</b>
<p>Te pliki mogą służyć jako ograniczenie dostępu dla autorów  i administratorów do innych części twojego serwisu (np. zewnętrznych statystyk).</p>
<p> Jeśli nie chcesz z nich korzystać, możesz pozostawić tą opcję
  w nienaruszonej postaci (te pliki nie zostaną stworzone).</p>', # MODIF
	'texte_informations_personnelles_1' => 'System stworzy teraz spersonalizowany dostep do serwisu.',
	'texte_informations_personnelles_2' => '(Informacja: jeśli jest to reinstalacja, a Twój dostęp wciąż działa, możesz',
	'texte_introductif_article' => '(Tekst wprowadzający do artykułu.)',
	'texte_jeu_caractere' => 'Zaleca się używania uniwersalnego kodowania (<tt>utf-8</tt>), co pozwala na wyświetlanie tekstów we wszystkich językach i jest kompatybilne ze wszystkimi współczesnymi przeglądarkami.',
	'texte_jeu_caractere_3' => 'Twoja strona pracuje obecnie w kodowaniu :',
	'texte_jeu_caractere_4' => 'Jeśli to nie odpowiada aktualnemu kodowaniu Twoich danych (np. po odtworzeniu bazy danych), lub jeśli <em>uruchamiasz stronę</em> i chcesz ustamić inne kodowanie, wpisz je tutaj:',
	'texte_login_ldap_1' => '(Pozostaw puste przy dostępie anonimowym, lub wpisz pełną ścieżkę, np. « <tt>uid=dupont, ou=users, dc=mon-domaine, dc=com</tt> ».)',
	'texte_login_precaution' => 'Uwaga ! To jest login, z którego pomocą jesteś teraz połączony.
 Używaj tego formularza ostrożnie...',
	'texte_messagerie_agenda' => 'System komunikacji umożliwia autorów na tej stronie do bezpośredniego komunikowania się na terenie prywatnym. Jest to związane z kalendarzem.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Właśnie zaktualizowałeś pliki SPIP.
 Teraz należy uaktualnić bazę danych
 Twojego serwisu.',
	'texte_modifier_article' => 'Edytuj artykuł',
	'texte_multilinguisme' => 'Jeśli planujesz edytować artykuły w wielu językach, ze złożoną nawigacją, możesz dołożyć do artykułu lub działu, menu wyboru języka, jako element organizacyjny Twojej strony.',
	'texte_multilinguisme_trad' => 'Możesz także włączyć system zarządzania linkami pomiędzy przekładami artykułów.',
	'texte_non_compresse' => '<i>nie skompresowany</i> (twój serwer nie posiada tej funkcji)',
	'texte_nouvelle_version_spip_1' => 'Nowa wersja SPIP została zainstalowana.',
	'texte_nouvelle_version_spip_2' => 'Nowa wersja wymaga bardziej kompletnego dostosowania niż zwykle. Jeśli jesteś administratorem strony wykasuj plik @connect@ z katalogu <tt>ecrire</tt> i powtórz instalację w celu uaktualnienia Twoich parametrów połączenia z bazą danych .<p> (NB. : jeśli zapomniałeś parametry połączenia, rzuć okiem do pliku @connect@ zanim go skasujesz...)</p>',
	'texte_operation_echec' => 'Powróć do poprzedniej strony, wybierz inną bazę danych lub stwórz nową. Sprawdź informacje podane przez twój serwis hostingowy.',
	'texte_plus_trois_car' => 'więcej niż 3 znaki',
	'texte_plusieurs_articles' => 'Kilku autorów zostało znalezionych dla "@cherche_auteur@":',
	'texte_port_annuaire' => '(Wartość podana domyślnie zwykle pasuje .)',
	'texte_presente_plugin' => 'Oto jest lista dostępnych rozszerzeń (pluginów). Możesz aktywować te rozszerzenia, których potrzebujesz, zaznaczając odpowiednie pole.',
	'texte_proposer_publication' => 'Gdy Twój artykuł jest ukończony,<br /> możesz zatwierdzić go do publikacji.',
	'texte_proxy' => 'W niektórych przypadkach (intranet, sieci chronione...),
  może zajść konieczność wykorzystania <i>proxy HTTP</i> aby dostać się do stron zrzeszonych.
  W innym przypadku, wpisz poniżej adres takiej strony, w postaci
  <tt><html>http://proxy:8080</html></tt>. Zwykle,
  to pole pozostaje wolne.',
	'texte_publication_articles_post_dates' => 'Jak powinien zachowywać się SPIP odnośnie artykułów,
  których data jest zaplanowana na
  przyszłość ?',
	'texte_rappel_selection_champs' => '[Nie zapomnij wybrać poprawnych pól.]',
	'texte_recalcul_page' => 'Jeśli chcesz 
odświeżyć tylko jedną stronę, zrób to z obszaru publicznego, używając przycisku « odśwież ».',
	'texte_recuperer_base' => 'Napraw bazę danych',
	'texte_reference_mais_redirige' => 'linki z artykułów w twoim serwisie SPIP, przekierowujące do innych URL-i.',
	'texte_requetes_echouent' => '<b>Jeśli pewne zapytania SQL nie udają się  regularnie i bez widocznego powodu, możliwe jest  że powodem tego jest baza danych</b><p>
 SQL ma możliwość naprawy poszczególnych tabel  jeśli przez przypadek zostały uszkodzone. Możesz spróbować naprawić je tutaj ; jeśli jednak nie powiedzie się taka operacja,  zachcowaj kopię wyświetlanego komunikatu, ponieważ może on zawierać wskazówki w czym tkwi poroblem.</p>
<p>Jeśli problem będzie się pojawiał często skontaktuj się z administratorem Twojego serwera.</p>',
	'texte_selection_langue_principale' => 'Możesz poniżej wybrać « główny język » serwisu. Ten wybór nie zmusza Cię - na szczęście ! - do pisania artykułów w wybranym języku, ale pozwala określić :
 <ul><li> domyślny format dat na stronach publicznych ;</li>
 <li> rodzaj kodowania tekstu, który ma używać SPIP ;</li>
 <li> język używany wa formularzach stron publicznych ;</li>
 <li> oraz język używany domyślnie w strefie prywatnej.</li></ul>',
	'texte_sous_titre' => 'Podtytuł',
	'texte_statistiques_visites' => '(ciemny pasek : niedziela / ciemna krzywa : rozwój średniej)',
	'texte_statut_attente_validation' => 'w trakcie zatwierdzania',
	'texte_statut_publies' => 'opublikowany online',
	'texte_statut_refuses' => 'odrzucony',
	'texte_suppression_fichiers' => 'Używaj tego polecenia gdy chcesz usunąć wszystkie pliki zapisane
 w cache SPIP. Pozwoli to na odświeżenie wszystkich stron, jeśli dokonaliści poważniejszych modyfikacji w układzie graficznym lub strukturze strony.',
	'texte_sur_titre' => 'Nadtytuł',
	'texte_table_ok' => ': ta tabela działa poprawnie.',
	'texte_tentative_recuperation' => 'Próba naprawy',
	'texte_tenter_reparation' => 'Spróbuj naprawić bazę danych',
	'texte_test_proxy' => 'Aby wypróbować proxy, wpisz tutaj adres strony internetowej
    którą chcesz przetestować.',
	'texte_titre_02' => 'Temat:',
	'texte_titre_obligatoire' => '<b>Tytuł</b> [Obowiązkowo]',
	'texte_travail_article' => '@nom_auteur_modif@ pracował nad tym artykułem @date_diff@ minut temu',
	'texte_travail_collaboratif' => 'Jeśli często zdarza się, że kilku redaktorów
   pracuje nad tym samym artykułem, system
  może wyświetlić artykuły ostatnio « otwarte »
  aby uniknąć jednoczesnego edytowania.
  Domyślnie ta opcja jest wyłączona
  w celu wyeliminowania niepotrzebnych komunikatów.', # MODIF
	'texte_vide' => 'pusty',
	'texte_vider_cache' => 'Opróżnij cache',
	'titre_admin_tech' => 'Konserwacja techniczna',
	'titre_ajouter_un_auteur' => 'Dodaj autora',
	'titre_ajouter_un_mot' => 'Dodaj słowo kluczowe',
	'titre_cadre_afficher_article' => 'Pokaż artykuły:',
	'titre_cadre_afficher_traductions' => 'Wyświetl stan przekładów dla następujących języków:',
	'titre_cadre_ajouter_auteur' => 'DODAJ ARTYKUŁY:',
	'titre_cadre_interieur_rubrique' => 'Artykuł znajduje się w dziale',
	'titre_cadre_numero_auteur' => 'AUTOR NUMER',
	'titre_cadre_numero_objet' => '@objet@ NUMBER:',
	'titre_cadre_signature_obligatoire' => '<b>Podpis</b> [Obowiązkowo]<br />',
	'titre_config_contenu_notifications' => 'Powiadomienia',
	'titre_config_contenu_prive' => 'W prywatnym miejscu',
	'titre_config_contenu_public' => 'Na stronie publicznej',
	'titre_config_fonctions' => 'Konfiguracja strony',
	'titre_config_langage' => 'Konfiguracja języka',
	'titre_configuration' => 'Konfiguracja strony',
	'titre_configurer_preferences' => 'Skonfiguruj swoje preferencje',
	'titre_configurer_preferences_menus' => 'Ustaw swoje preferencje menu.',
	'titre_conflit_edition' => 'Konflikt podczas edycji',
	'titre_connexion_ldap' => 'Opcje: <b>Twoje połączenie LDAP</b>',
	'titre_groupe_mots' => 'GRUPY SŁÓW KLUCZOWYCH:',
	'titre_identite_site' => 'Tożsamość strony',
	'titre_langue_article' => 'Język artykułu', # RELIRE
	'titre_langue_rubrique' => 'Język działu',
	'titre_langue_trad_article' => 'JĘZYK I TŁUMACZENIA ARTYKUŁU',
	'titre_les_articles' => 'ARTYKUŁY',
	'titre_messagerie_agenda' => 'System komunikacji i kalendarz',
	'titre_naviguer_dans_le_site' => 'Przeglądaj stronę...',
	'titre_nouvelle_rubrique' => 'Nowy dział',
	'titre_numero_rubrique' => 'DZIAŁ NUMER :',
	'titre_page_articles_edit' => 'Edytuj: @titre@',
	'titre_page_articles_page' => 'Artykuły',
	'titre_page_articles_tous' => 'Cała strona',
	'titre_page_calendrier' => 'Kalendarz @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Konfiguracja strony',
	'titre_page_delete_all' => 'całkowite i nieodwracalne usunięcie',
	'titre_page_recherche' => 'Wyniki wyszukiwania @recherche@',
	'titre_page_statistiques_referers' => 'Statystyki (linki wchodzące)',
	'titre_page_upgrade' => 'Dostosowanie SPIP',
	'titre_preference_menus_favoris' => 'Ulubione menu',
	'titre_publication_articles_post_dates' => 'Publikacja post-datowanych artykułów',
	'titre_reparation' => 'Napraw',
	'titre_suivi_petition' => 'Archiwum ogłoszeń',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Wszystkie wersje tego artykułu:',
	'trad_delier' => 'Nie łączyć z tymi tłumaczeniami',
	'trad_lier' => 'Ten artykuł jest przekładem artykułu numer',
	'trad_new' => 'Napisz nowe tłumaczenie artykułu',

	// U
	'utf8_convert_erreur_orig' => 'Błąd : kodowanie @charset@ nie jest wspierane.',

	// V
	'version' => 'Wersja :',
];
